Support — django-shortwave v0.9.1 documentation

### Navigation

- index
- modules |
- previous |
- django-shortwave v0.9.1 documentation »

# Support

## `django-shortwave`

Bugs and feature requests regarding `django-shortwave` can be submitted to the GitHub issue tracker.

This package does not yet have a complete test suite, but it will be completed in the near future.

If you feel like contributing to the project, you can fork the repository on GitHub.

## Shortwave

Questions regarding Shortwave itself should be directed to its creator, Shaun Inman.

### Navigation

- index
- modules |
- previous |
- django-shortwave v0.9.1 documentation »